==> json_users_import-1.0.0-beta1.tar.gz: json_users_import/src/Form/JsonUsersImport.php <==
<?php

namespace Drupal\json_users_import\Form;

use Drupal\Core\Form\Formbase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\user\Entity\User;
use Drupal\Component\Serialization\Json;
use Drupal\Component\Utility\Random;

/**
 * Provide a form to import the users from Json
 */
class JsonUsersImport extends Formbase
{
	
	/**
	 * Implements \Drupal\Core\Form\FormInterface::getFormID().
	 */
	public function getFormId() {
		return 'json_users_import_form';
	}

	public function buildForm(array $form, FormStateInterface $form_state) {
		
		$form['user_import_config'] = [
			'#type' => 'details',
			'#title' => t('User Import Configuration'),
			'#attributes' => ['id' => ['user_import_config']],
			'#open' => TRUE,
		];
		$form['user_import_config']['jsonDataKey'] = [
			'#type' => 'textarea',
			'#title' => t("Map the data with appropriate key (name & email keys are mandatory)"),
			'#description' => '<p>' . t('Enter one value per line, in the format fieldname|datakey.') .'<span> Use email as the fieldname for email and name as the fieldname for username in the json.</span></p><p>'. t('The fieldname is the machine name of the fields in the ').'<a href="admin/config/people/accounts/fields">'. t('user account settings') .'.</a>'.t( ' The jsondatakey is the key in the json data.'). '<span> Ex: [{"useremail": "test@test.com","username": "testuser"}].</span></p><p>From above ex, useremail is the jsondatakey. So we need to configure like email|useremail & name|username one by one.</p><p> We can add custom fields and map the key as per your need.</p>',
			'#required' => TRUE,
		];
		$form['user_import'] = [
	      '#title' => $this->t('Paste your json here'),
	      '#type' => 'textarea',
	      '#rows' => 24,
	      '#required' => TRUE,
	    ];
	    $form['actions'] = ['#type' => 'actions'];
	    $form['actions']['submit'] = [
	      '#type' => 'submit',
	      '#value' => $this->t('Import'),
	      '#button_type' => 'primary',
	    ];
		return $form;
	}

	public function validateForm(array &$form, FormStateInterface $form_state) {

	}

	public function submitForm(array &$form, FormStateInterface $form_state) {
		$jsonDataKey = $form_state->getValue('jsonDataKey');
		$splitKey = explode(PHP_EOL, $jsonDataKey);
		foreach ($splitKey as $value) {
			$splitKeyarray = explode('|', $value);
			$jsonKey[$splitKeyarray[0]] = $splitKeyarray[1];
		}
		$isEmailExist = '';
		$emailKey = $jsonKey['email'];
		$usernameKey = $jsonKey['name'];
		$users_json = $form_state->getValue('user_import');
		$json_decoded = Json::decode($users_json);
		if(is_array($json_decoded)) {
			foreach ($json_decoded as $key => $value) {
				$isUserNameValid = self::isUserNameValid($value[$usernameKey]);
				if($isUserNameValid['valid']) {
					$isEmailExist = self::isEmailExist($value[$emailKey]);
					$isUserNameExist = self::isUserNameExist($value[$usernameKey]);
					if($isEmailExist['id']) {
						\Drupal::messenger()->addMessage($isEmailExist['returnMsg']);
					} else if($isUserNameExist['id']) {
						\Drupal::messenger()->addMessage($isUserNameExist['returnMsg']);
					} else {
						$password = Random::name(7);
						$user = User::create();
						$user->setEmail($value[$emailKey]);
						$user->setUsername($value[$usernameKey]);
						$user->setPassword($password);
						$user->enforceIsNew();
						$user->activate();
						// Save user account.
						$ignoreFields = array("email", "name", "password");
						foreach($jsonKey as $fieldName => $fieldValue) {
							if (!in_array($fieldName, $ignoreFields)) {
								$user->set($fieldName,$value[$fieldValue]);
							}
						}
						$result = $user->save();
						if ($user->isActive()) {
							$successMsg = 'User '. $value[$usernameKey] .' is created successfully!';
							\Drupal::messenger()->addMessage($successMsg);
						}
					}
				} else {
					\Drupal::messenger()->addMessage($isUserNameValid['returnMsg']);
				}
			}
		} else {
			\Drupal::messenger()->addMessage("Not a valid Json!");
		}
	}

	// public function submitForm(array &$form, FormStateInterface $form_state) {
	// 	$jsonDataKey = $form_state->getValue('jsonDataKey');
	// 	$splitKey = explode(PHP_EOL, $jsonDataKey);
	// 	foreach ($splitKey as $value) {
	// 		$splitKeyarray = explode('|', $value);
	// 		$jsonKey[$splitKeyarray[0]] = $splitKeyarray[1];
	// 		//print_r($splitKeyarray);
	// 		//$aaa = 'aaaaa';
	// 	// 	// foreach ($value as $key => $value) {
	// 	// 	// 	# code...
	// 	// 	// }
	// 	// 	//$splitKeyarray[$key] = explode('|', $value);
	// 	// 	// echo 'splitKeyarray <pre>';
	// 	// 	// print_r($splitKeyarray[$key]);
	// 	// 	// echo ' val <pre>';
	// 	// 	// print_r($value);
	// 	// 	//echo '<br>';
	// 	}

	// 	// foreach ($splitKeyarray as $value) {
	// 	// 	echo '<pre>';
	// 	// 	print_r($key);
	// 	// 	echo '<pre>';
	// 	// 	print_r($value);
	// 	// 	echo '<br>';
	// 	// }
	// 	// echo '<pre>';print_r($splitKeyarray);
	// 	//exit;
	// 	$isEmailExist = '';
	// 	// $emailKey = $form_state->getValue('emailKey');
	// 	$emailKey = $jsonKey['email'];
	// 	$usernameKey = $jsonKey['name'];
	// 	// print_r($emailKey);
	// 	// print_r($usernameKey);
	// 	// exit;
	// 	// $usernameKey = $form_state->getValue('usernameKey');
	// 	// $usernameKey = $form_state->getValue('usernameKey');
	// 	$users_json = $form_state->getValue('user_import');
	// 	$json_decoded = Json::decode($users_json);
	// 	if(is_array($json_decoded)) {
	// 		foreach ($json_decoded as $key => $value) {
	// 			$isUserNameValid = self::isUserNameValid($value[$usernameKey]);
	// 			if($isUserNameValid['valid']) {
	// 				$isEmailExist = self::isEmailExist($value[$emailKey]);
	// 				$isUserNameExist = self::isUserNameExist($value[$usernameKey]);
	// 				if($isEmailExist['id']) {
	// 					\Drupal::messenger()->addMessage($isEmailExist['returnMsg']);
	// 				} else if($isUserNameExist['id']) {
	// 					\Drupal::messenger()->addMessage($isUserNameExist['returnMsg']);
	// 				} else {
	// 					$user = User::create();
	// 					$user->setEmail($value[$emailKey]);
	// 					$user->setUsername($value[$usernameKey]);
	// 					$user->setPassword($value['password']);
	// 					$user->enforceIsNew();
	// 					$user->activate();
	// 					// Save user account.
	// 					$avoidFields = array("email", "name", "password");
	// 					if (!in_array($jsonKey['email'], $avoidFields)) {
	// 					    echo "BB is not found";
	// 					}
	// 					$user->set('...','....');
	// 					$result = $user->save();
	// 					if ($user->isActive()) {
	// 						$successMsg = 'User '. $value[$usernameKey] .' is created successfully!';
	// 						\Drupal::messenger()->addMessage($successMsg);
	// 					}
	// 				}
	// 			} else {
	// 				\Drupal::messenger()->addMessage($isUserNameValid['returnMsg']);
	// 			}
	// 		}
	// 	} else {
	// 		\Drupal::messenger()->addMessage("Not a valid Json!");
	// 	}
	// }

	public function isEmailExist($email) {
		//print_r('expression');exit;
		$userId = \Drupal::entityQuery('user')->condition('mail', $email)->execute();
		$userId = array_shift($userId);
		if($userId > 0) {
			return array ('id' => $userId, 'returnMsg' => $email.' is already exists!');
		}
	}

	public function isUserNameExist($username) {
		$userId = \Drupal::entityQuery('user')->condition('name', $username)->range(0, 1)
        ->execute();
		//print_r($userId);exit;
		$userId = array_shift($userId);
		if($userId > 0) {
			return array ('id' => $userId, 'returnMsg' => $username.' is already exists!');
		}
	}

	public function isUserNameValid($username) {
		$valid = TRUE;
		if (substr($username, 0, 1) == ' ') {
			$valid = FALSE;
			$returnMsg = $username .' cannot begin with a space.';
		} else if (substr($username, -1) == ' ') {
			$valid = FALSE;
			$returnMsg = $username .' cannot end with a space.';
		} else if (strpos($username, '  ') !== FALSE) {
			$valid = FALSE;
			$returnMsg = $username .' cannot contain multiple spaces.';
		} else if (preg_match('/[^\x{80}-\x{F7} a-z0-9@+_.\'-]/i', $username)) {
			$valid = FALSE;
			$returnMsg = $username .' contains an illegal character.';
		} else if (mb_strlen($username) > 60 ) {
			$valid = FALSE;
			$returnMsg = $username .' is too long, it must be 60 characters or less.';
		}
		return array ('valid' => $valid, 'returnMsg' => $returnMsg);
	}
}

==> json_users_import-1.0.2-beta1.tar.gz: json_users_import/src/Form/JsonUsersImport.php <==
<?php

namespace Drupal\json_users_import\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Serialization\Json;
use Drupal\json_users_import\Controller\JsonUsersImportController;

/**
 * Provides a form to import the users from Json
 */
class JsonUsersImport extends FormBase {
	
	/**
	 * Implements \Drupal\Core\Form\FormInterface::getFormID().
	 */
	public function getFormId() {
		return 'json_users_import_form';
	}

	/**
   * {@inheritdoc}
   */
	public function buildForm(array $form, FormStateInterface $form_state) {
		
		$form['user_import_config'] = [
			'#type' => 'details',
			'#title' => t('User Import Configuration'),
			'#attributes' => ['id' => ['user_import_config']],
			'#open' => TRUE,
		];
		$form['user_import_config']['jsonDataKey'] = [
			'#type' => 'textarea',
			'#title' => t("Map the data with appropriate key (name & email keys are mandatory)"),
			'#description' => '<p>' . t('Enter one value per line, in the format fieldname|datakey.') .'<span> Use email as the fieldname for email and name as the fieldname for username in the json.</span></p><p>'. t('The fieldname is the machine name of the fields in the ').'<a href="admin/config/people/accounts/fields">'. t('user account settings') .'.</a>'.t( ' The jsondatakey is the key in the json data.'). '<span> Ex: [{"useremail": "test@test.com","username": "testuser"}].</span></p><p>From above ex, useremail is the jsondatakey. So we need to configure like email|useremail & name|username one by one.</p><p> We can add custom fields and map the key as per your need.</p>',
			'#required' => TRUE,
		];
		$form['user_import'] = [
	      '#title' => $this->t('Paste your json here'),
	      '#type' => 'textarea',
	      '#rows' => 24,
	      '#required' => TRUE,
	    ];
	    $form['actions'] = ['#type' => 'actions'];
	    $form['actions']['submit'] = [
	      '#type' => 'submit',
	      '#value' => $this->t('Import'),
	      '#button_type' => 'primary',
	    ];
		return $form;
	}

	/**
   * {@inheritdoc}
   */
	public function validateForm(array &$form, FormStateInterface $form_state) {

	}

	/**
   * {@inheritdoc}
   */
	public function submitForm(array &$form, FormStateInterface $form_state) {
		$jsonDataKey = $form_state->getValue('jsonDataKey');
		$splitKey = explode(PHP_EOL, $jsonDataKey);
		foreach ($splitKey as $value) {
			$splitKeyarray = explode('|', $value);
			$jsonKey[$splitKeyarray[0]] = $splitKeyarray[1];
		}
		$users_json = $form_state->getValue('user_import');
		$json_decoded = Json::decode($users_json);
		if(is_array($json_decoded)) {
			$operations = [['creating_users_batch', [$json_decoded, $jsonKey]]];
      $batch = [
        'title' => $this->t('Creating Users ...'),
        'operations' => $operations,
        'finished' => 'users_finished_batch',
      ];
      batch_set($batch);
		} else {
			\Drupal::messenger()->addMessage("Not a valid Json!");
		}
	}
}
